@@ -1,3 +1,85 @@
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+#################### GENERAL OBJECT UTILITIES ####################
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+
+#' Merge a list of Seurat Objects
+#'
+#' Enables easy merge of a list of Seurat Objects.  See  See \code{\link[SeuratObject]{merge}} for more information,
+#'
+#' @param list_seurat list composed of multiple Seurat Objects.
+#' @param add.cell.ids A character vector of equal length to the number of objects in `list_seurat`.
+#' Appends the corresponding values to the start of each objects' cell names.  See \code{\link[SeuratObject]{merge}}.
+#' @param merge.data Merge the data slots instead of just merging the counts (which requires renormalization).
+#' This is recommended if the same normalization approach was applied to all objects.
+#' See \code{\link[SeuratObject]{merge}}.
+#' @param project Project name for the Seurat object. See \code{\link[SeuratObject]{merge}}.
+#'
+#' @import cli
+#' @importFrom magrittr "%>%"
+#' @importFrom purrr reduce
+#'
+#' @return A Seurat Object
+#'
+#' @export
+#'
+#' @concept object_util
+#'
+#' @examples
+#' \dontrun{
+#' object_list <- list(obj1, obj2, obj3, ...)
+#' merged_object <- Merge_Seurat_List(list_seurat = object_list)
+#' }
+#'
+
+Merge_Seurat_List <- function(
+    list_seurat,
+    add.cell.ids = NULL,
+    merge.data = TRUE,
+    project = "SeuratProject"
+) {
+  # Check list_seurat is list
+  if (!inherits(x = list_seurat, what = "list")) {
+    cli_abort(message = "{.code list_seurat} must be environmental variable of class {.val list}")
+  }
+
+  # Check list_seurat is only composed of Seurat objects
+  for (i in 1:length(x = list_seurat)) {
+    if (!inherits(x = list_seurat[[i]], what = "Seurat")) {
+      cli_abort("One or more of entries in {.code list_seurat} are not objects of class {.val Seurat}")
+    }
+  }
+
+  # Check all barcodes are unique to begin with
+  duplicated_barcodes <- list_seurat %>%
+    lapply(colnames) %>%
+    unlist() %>%
+    duplicated() %>%
+    any()
+
+  if (isTRUE(x = duplicated_barcodes) && is.null(x = add.cell.ids)) {
+    cli_abort(message = c("There are overlapping cell barcodes present in the input objects",
+                          "i" = "Please rename cells or provide prefixes to {.code add.cell.ids} parameter to make unique.")
+    )
+  }
+
+  # Check right number of suffix/prefix ids are provided
+  if (!is.null(x = add.cell.ids) && length(x = add.cell.ids) != length(x = list_seurat)) {
+    cli_abort(message = "The number of prefixes in {.code add.cell.ids} must be equal to the number of objects supplied to {.code list_seurat}.")
+  }
+
+  # Rename cells if provided
+  list_seurat <- lapply(1:length(x = list_seurat), function(x) {
+    list_seurat[[x]] <- RenameCells(object = list_seurat[[x]], add.cell.id = add.cell.ids[x])
+  })
+
+  # Merge objects
+  merged_object <- reduce(list_seurat, function(x, y) {
+    merge(x = x, y = y, merge.data = merge.data, project = project)
+  })
+}
+
+
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 #################### QC UTILITIES ####################
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -14,9 +96,9 @@
 #' @param mito_name name to use for the new meta.data column containing percent mitochondrial counts.
 #' Default is "percent_mito".
 #' @param ribo_name name to use for the new meta.data column containing percent ribosomal counts.
-#' Default is "percent_mito".
+#' Default is "percent_ribo".
 #' @param mito_ribo_name name to use for the new meta.data column containing percent
-#' mitochondrial+ribosomal counts.  Default is "percent_mito".
+#' mitochondrial+ribosomal counts.  Default is "percent_mito_ribo".
 #' @param mito_pattern A regex pattern to match features against for mitochondrial genes (will set automatically if
 #' species is mouse or human; marmoset features list saved separately).
 #' @param ribo_pattern A regex pattern to match features against for ribosomal genes
@@ -48,8 +130,9 @@
 #' @concept object_util
 #'
 #' @examples
-#' library(Seurat)
-#' pbmc_small <- Add_Mito_Ribo_Seurat(seurat_object = pbmc_small, species = "human")
+#' \dontrun{
+#' obj <- Add_Mito_Ribo_Seurat(seurat_object = obj, species = "human")
+#'}
 #'
 
 Add_Mito_Ribo_Seurat <- function(
@@ -79,7 +162,7 @@ Add_Mito_Ribo_Seurat <- function(
   )
 
   # Return list of accepted default species name options
-  if (list_species_names) {
+  if (isTRUE(x = list_species_names)) {
     return(accepted_names)
     stop_quietly()
   }
@@ -94,7 +177,7 @@ Add_Mito_Ribo_Seurat <- function(
 
   # Overwrite check
   if (mito_name %in% colnames(x = seurat_object@meta.data) || ribo_name %in% colnames(x = seurat_object@meta.data) || mito_ribo_name %in% colnames(x = seurat_object@meta.data)) {
-    if (!overwrite) {
+    if (isFALSE(x = overwrite)) {
       cli_abort(message = c("Columns with {.val {mito_name}} and/or {.val {ribo_name}} already present in meta.data slot.",
                             "i" = "*To run function and overwrite columns set parameter {.code overwrite = TRUE} or change respective {.code mito_name}, {.code ribo_name}, and/or {.code mito_ribo_name}*")
       )
@@ -124,7 +207,7 @@ Add_Mito_Ribo_Seurat <- function(
   macaque_options <- accepted_names$Macaque_Options
 
   # Check ensembl vs patterns
-  if (ensembl_ids && species %in% c(mouse_options, human_options, marmoset_options, zebrafish_options, rat_options, drosophila_options) && any(!is.null(x = mito_pattern), !is.null(x = ribo_pattern), !is.null(x = mito_features), !is.null(x = ribo_features))) {
+  if (isTRUE(x = ensembl_ids) && species %in% c(mouse_options, human_options, marmoset_options, zebrafish_options, rat_options, drosophila_options) && any(!is.null(x = mito_pattern), !is.null(x = ribo_pattern), !is.null(x = mito_features), !is.null(x = ribo_features))) {
     cli_warn(message = c("When using a default species and setting {.code ensembl_ids = TRUE} provided patterns or features are ignored.",
                          "*" = "Supplied {.code mito_pattern}, {.code ribo_pattern}, {.code mito_features}, {.code ribo_features} will be disregarded.")
     )
@@ -164,13 +247,13 @@ Add_Mito_Ribo_Seurat <- function(
   }
 
   # Check that values are provided for mito and ribo
-  if (is.null(x = mito_pattern) && is.null(x = mito_features) && is.null(x = ribo_pattern) && is.null(x = ribo_pattern)) {
+  if (is.null(x = mito_pattern) && is.null(x = mito_features) && is.null(x = ribo_pattern) && is.null(x = ribo_features)) {
     cli_abort(message = c("No features or patterns provided for mito/ribo genes.",
                           "i" = "Please provide a default species name or pattern/features."))
   }
 
   # Retrieve ensembl ids if TRUE
-  if (ensembl_ids) {
+  if (isTRUE(x = ensembl_ids)) {
     mito_features <- Retrieve_Ensembl_Mito(species = species)
     ribo_features <- Retrieve_Ensembl_Ribo(species = species)
   }
@@ -273,7 +356,7 @@ Add_Cell_Complexity_Seurat <- function(
 
   # Check columns for overwrite
   if (meta_col_name %in% colnames(x = seurat_object@meta.data)) {
-    if (!overwrite) {
+    if (isFALSE(x = overwrite)) {
       cli_abort(message = c("Column {.val {meta_col_name}} already present in meta.data slot.",
                             "i" = "*To run function and overwrite column, set parameter {.code overwrite = TRUE} or change respective {.code meta_col_name}*.")
       )
@@ -295,6 +378,305 @@ Add_Cell_Complexity_Seurat <- function(
 }
 
 
+#' Add Percent of High Abundance Genes
+#'
+#' Add the percentage of counts occupied by the top XX most highly expressed genes in each cell.
+#'
+#' @param seurat_object object name.
+#' @param num_top_genes An integer vector specifying the size(s) of the top set of high-abundance genes.
+#' Used to compute the percentage of library size occupied by the most highly expressed genes in each cell.
+#' @param meta_col_name name to use for new meta data column.  Default is "percent_topXX", where XX is
+#' equal to the value provided to `num_top_genes`.
+#' @param assay assay to use in calculation.  Default is "RNA".  *Note* This should only be changed if
+#' storing corrected and uncorrected assays in same object (e.g. outputs of both Cell Ranger and Cell Bender).
+#' @param overwrite Logical.  Whether to overwrite existing an meta.data column.  Default is FALSE meaning that
+#' function will abort if column with name provided to `meta_col_name` is present in meta.data slot.
+#'
+#' @import cli
+#' @importFrom dplyr select all_of
+#' @importFrom magrittr "%>%"
+#' @importFrom rlang is_installed
+#' @importFrom SeuratObject LayerData
+#'
+#' @return A Seurat Object
+#'
+#' @export
+#'
+#' @concept object_util
+#'
+#'
+#' @references This function uses scuttle package (license: GPL-3) to calculate the percent of expression
+#' coming from top XX genes in each cell.  Parameter description for `num_top_genes` also from scuttle.
+#' If using this function in analysis, in addition to citing scCustomize, please cite scuttle:
+#' McCarthy DJ, Campbell KR, Lun ATL, Willis QF (2017). “Scater: pre-processing, quality control,
+#' normalisation and visualisation of single-cell RNA-seq data in R.” Bioinformatics, 33, 1179-1186.
+#' \url{doi:10.1093/bioinformatics/btw777}.
+#' @seealso \url{https://bioconductor.org/packages/release/bioc/html/scuttle.html}
+#'
+#' @examples
+#' \dontrun{
+#' library(Seurat)
+#' pbmc_small <- Add_Top_Gene_Pct_Seurat(seurat_object = pbmc_small, num_top_genes = 50)
+#' }
+#'
+
+Add_Top_Gene_Pct_Seurat <- function(
+    seurat_object,
+    num_top_genes = 50,
+    meta_col_name = NULL,
+    assay = "RNA",
+    overwrite = FALSE
+){
+  # Check for scuttle first
+  scuttle_check <- is_installed(pkg = "scuttle")
+  if (isFALSE(x = scuttle_check)) {
+    cli_abort(message = c(
+      "Please install the {.val scuttle} package to calculate/add top {num_top_genes} genes percentage.",
+      "i" = "This can be accomplished with the following commands: ",
+      "----------------------------------------",
+      "{.field `install.packages({symbol$dquote_left}BiocManager{symbol$dquote_right})`}",
+      "{.field `BiocManager::install({symbol$dquote_left}scuttle{symbol$dquote_right})`}",
+      "----------------------------------------"
+    ))
+  }
+
+  # Check Seurat
+  Is_Seurat(seurat_object = seurat_object)
+
+  # Add assay warning message
+  if (assay != "RNA") {
+    cli_warn(message = "Assay is set to value other than 'RNA'. This should only be done in rare instances.  See documentation for more info ({.code ?Add_Top_Gene_Pct_Seurat}).",
+             .frequency = "once",
+             .frequency_id = "assay_warn")
+  }
+
+  # Set colnames
+  scuttle_colname <- paste0("percent.top_", num_top_genes)
+  if (is.null(x = meta_col_name)) {
+    meta_col_name <- paste0("percent_top", num_top_genes)
+  }
+
+  # Check columns for overwrite
+  if (meta_col_name %in% colnames(x = seurat_object@meta.data)) {
+    if (isFALSE(x = overwrite)) {
+      cli_abort(message = c("Column {.val {meta_col_name}} already present in meta.data slot.",
+                            "i" = "*To run function and overwrite column, set parameter {.code overwrite = TRUE} or change respective {.code meta_col_name}*.")
+      )
+    }
+    cli_inform(message = c("Column {.val {meta_col_name}} already present in meta.data slot",
+                           "i" = "Overwriting those columns as {.code overwrite = TRUE}.")
+    )
+  }
+
+  # Extract matrix
+  count_mat <- LayerData(object = seurat_object, assay = assay)
+
+  # calculate
+  res <- as.data.frame(scuttle::perCellQCMetrics(x = count_mat, percent.top = num_top_genes))
+
+  # select percent column
+  res <- res %>%
+    select(all_of(scuttle_colname))
+
+  # Add to object and return
+  seurat_object <- AddMetaData(object = seurat_object, metadata = res, col.name = meta_col_name)
+
+  return(seurat_object)
+}
+
+
+#' Add Multiple Cell Quality Control Values with Single Function
+#'
+#' Add Mito/Ribo %, Cell Complexity (log10GenesPerUMI), Top Gene Percent with single function call
+#'
+#' @param seurat_object object name.
+#' @param add_mito_ribo logical, whether to add percentage of counts belonging to mitochondrial/ribosomal
+#' genes to object (Default is TRUE).
+#' @param add_complexity logical, whether to add Cell Complexity to object (Default is TRUE).
+#' @param add_top_pct logical, whether to add Top Gene Percentages to object (Default is TRUE).
+#' @param add_MSigDB logical, whether to add percentages of counts belonging to genes from of mSigDB hallmark
+#' gene lists: "HALLMARK_OXIDATIVE_PHOSPHORYLATION", "HALLMARK_APOPTOSIS", and "HALLMARK_DNA_REPAIR" to
+#' object (Default is TRUE).
+#' @param add_IEG logical, whether to add percentage of counts belonging to IEG genes to object (Default is TRUE).
+#' @param add_cell_cycle logical, whether to addcell cycle scores and phase based on
+#' \code{\link[Seurat]{CellCycleScoring}}.  Only applicable if `species = "human"`.  (Default is TRUE).
+#' @param species Species of origin for given Seurat Object.  If mouse, human, marmoset, zebrafish, rat,
+#' drosophila, or rhesus macaque (name or abbreviation) are provided the function will automatically
+#' generate mito_pattern and ribo_pattern values.
+#' @param mito_name name to use for the new meta.data column containing percent mitochondrial counts.
+#' Default is "percent_mito".
+#' @param ribo_name name to use for the new meta.data column containing percent ribosomal counts.
+#' Default is "percent_ribo".
+#' @param mito_ribo_name name to use for the new meta.data column containing percent
+#' mitochondrial+ribosomal counts.  Default is "percent_mito_ribo".
+#' @param complexity_name name to use for new meta data column for `Add_Cell_Complexity_Seurat`.
+#' Default is "log10GenesPerUMI".
+#' @param top_pct_name name to use for new meta data column for `Add_Top_Gene_Pct_Seurat`.
+#' Default is "percent_topXX", where XX is equal to the value provided to `num_top_genes`.
+#' @param oxphos_name name to use for new meta data column for percentage of MSigDB oxidative phosphorylation
+#' counts.  Default is "percent_oxphos".
+#' @param apop_name name to use for new meta data column for percentage of MSigDB apoptosis counts.
+#' Default is "percent_apop".
+#' @param dna_repair_name name to use for new meta data column for percentage of MSigDB DNA repair
+#' counts.  Default is "percent_dna_repair"..
+#' @param ieg_name name to use for new meta data column for percentage of IEG counts.  Default is "percent_ieg".
+#' @param mito_pattern A regex pattern to match features against for mitochondrial genes (will set automatically if
+#' species is mouse or human; marmoset features list saved separately).
+#' @param ribo_pattern A regex pattern to match features against for ribosomal genes
+#' (will set automatically if species is mouse, human, or marmoset).
+#' @param mito_features A list of mitochondrial gene names to be used instead of using regex pattern.
+#' Will override regex pattern if both are present (including default saved regex patterns).
+#' @param ribo_features A list of ribosomal gene names to be used instead of using regex pattern.
+#' Will override regex pattern if both are present (including default saved regex patterns).
+#' @param ensembl_ids logical, whether feature names in the object are gene names or
+#' ensembl IDs (default is FALSE; set TRUE if feature names are ensembl IDs).
+#' @param num_top_genes An integer vector specifying the size(s) of the top set of high-abundance genes.
+#' Used to compute the percentage of library size occupied by the most highly expressed genes in each cell.
+#' @param assay assay to use in calculation.  Default is "RNA".  *Note* This should only be changed if
+#' storing corrected and uncorrected assays in same object (e.g. outputs of both Cell Ranger and Cell Bender).
+#' @param overwrite Logical.  Whether to overwrite existing an meta.data column.  Default is FALSE meaning that
+#' function will abort if column with name provided to `meta_col_name` is present in meta.data slot.
+#'
+#' @import cli
+#' @importFrom SeuratObject Layers
+#'
+#' @return A Seurat Object
+#'
+#' @export
+#'
+#' @concept object_util
+#'
+#' @examples
+#' \dontrun{
+#' obj <- Add_Cell_QC_Metrics(seurat_object = obj, species = "Human")
+#'}
+#'
+
+Add_Cell_QC_Metrics <- function(
+    seurat_object,
+    add_mito_ribo = TRUE,
+    add_complexity = TRUE,
+    add_top_pct = TRUE,
+    add_MSigDB = TRUE,
+    add_IEG = TRUE,
+    add_cell_cycle = TRUE,
+    species,
+    mito_name = "percent_mito",
+    ribo_name = "percent_ribo",
+    mito_ribo_name = "percent_mito_ribo",
+    complexity_name = "log10GenesPerUMI",
+    top_pct_name = NULL,
+    oxphos_name = "percent_oxphos",
+    apop_name = "percent_apop",
+    dna_repair_name = "percent_dna_repair",
+    ieg_name = "percent_ieg",
+    mito_pattern = NULL,
+    ribo_pattern = NULL,
+    mito_features = NULL,
+    ribo_features = NULL,
+    ensembl_ids = FALSE,
+    num_top_genes = 50,
+    assay = NULL,
+    overwrite = FALSE
+) {
+  # Set assay
+  assay <- assay %||% DefaultAssay(object = seurat_object)
+
+  # Accepted species names
+  accepted_names <- data.frame(
+    Mouse_Options = c("Mouse", "mouse", "Ms", "ms", "Mm", "mm"),
+    Human_Options = c("Human", "human", "Hu", "hu", "Hs", "hs"),
+    Marmoset_Options = c("Marmoset", "marmoset", "CJ", "Cj", "cj", NA),
+    Zebrafish_Options = c("Zebrafish", "zebrafish", "DR", "Dr", "dr", NA),
+    Rat_Options = c("Rat", "rat", "RN", "Rn", "rn", NA),
+    Drosophila_Options = c("Drosophila", "drosophila", "DM", "Dm", "dm", NA),
+    Macaque_Options = c("Macaque", "macaque", "Rhesus", "macaca", "mmulatta", NA)
+  )
+
+  # Species Spelling Options
+  mouse_options <- accepted_names$Mouse_Options
+  human_options <- accepted_names$Human_Options
+  marmoset_options <- accepted_names$Marmoset_Options
+  zebrafish_options <- accepted_names$Zebrafish_Options
+  rat_options <- accepted_names$Rat_Options
+  drosophila_options <- accepted_names$Drosophila_Options
+  macaque_options <- accepted_names$Macaque_Options
+
+  # Add mito/ribo
+  if (isTRUE(x = add_mito_ribo)) {
+    cli_inform(message = "Adding {.field Mito/Ribo Percentages} to meta.data.")
+    seurat_object <- Add_Mito_Ribo_Seurat(seurat_object = seurat_object, species = species, mito_name = mito_name, ribo_name = ribo_name, mito_ribo_name = mito_ribo_name, mito_pattern = mito_pattern, ribo_pattern = ribo_pattern, mito_features = mito_features, ribo_features = ribo_features, ensembl_ids = ensembl_ids, assay = assay, overwrite = overwrite)
+  }
+
+  # Add complexity
+  if (isTRUE(x = add_complexity)) {
+    cli_inform(message = "Adding {.field Cell Complexity #1 (log10GenesPerUMI)} to meta.data.")
+    seurat_object <- Add_Cell_Complexity_Seurat(seurat_object = seurat_object, meta_col_name = complexity_name, assay = assay, overwrite = overwrite)
+  }
+
+  # Add top gene expression percent
+  if (isTRUE(x = add_top_pct)) {
+    cli_inform(message = "Adding {.field Cell Complexity #2 (Top {num_top_genes} Percentages)} to meta.data.")
+    seurat_object <- Add_Top_Gene_Pct_Seurat(seurat_object = seurat_object, num_top_genes = num_top_genes, meta_col_name = top_pct_name, assay = assay, overwrite = overwrite)
+  }
+
+  # Add MSigDB
+  if (isTRUE(x = add_MSigDB)) {
+    if (species %in% marmoset_options) {
+      cli_warn(message = c("{.val Marmoset} is not currently a part of MSigDB gene list database.",
+                           "i" = "No columns will be added to object meta.data"))
+    } else {
+      cli_inform(message = "Adding {.field MSigDB Oxidative Phosphorylation, Apoptosis, and DNA Repair Percentages} to meta.data.")
+      seurat_object <- Add_MSigDB_Seurat(seurat_object = seurat_object, species = species, oxphos_name = oxphos_name, apop_name = apop_name, dna_repair_name = dna_repair_name, assay = assay, overwrite = overwrite)
+    }
+  }
+
+  # Add IEG
+  if (isTRUE(x = add_IEG)) {
+    if (species %in% c(marmoset_options, rat_options, zebrafish_options, macaque_options, drosophila_options)) {
+      cli_warn(message = c("{.val Rat, Marmoset, Macaque, Zebrafish, and Drosophila} are not currently supported.",
+                           "i" = "No column will be added to object meta.data"))
+    } else {
+      cli_inform(message = "Adding {.field IEG Percentages} to meta.data.")
+      seurat_object <- Add_IEG_Seurat(seurat_object = seurat_object, species = species, ieg_name = ieg_name, assay = assay, overwrite = overwrite)
+    }
+  }
+
+  if (isTRUE(x = add_cell_cycle)) {
+    if (!species %in% human_options) {
+      cli_abort(message = c("Cell Cycle Scoring is only supported for human in this function.",
+                            "i" = "To add score for other species supply cell cycle gene list of `CellCycleScoring` function."
+                ))
+    } else {
+      if (length(grep(x = Layers(object = seurat_object), pattern = "data", value = T)) == 0) {
+        cli_inform(message = c("Layer with normalized data not present.",
+                               "i" = "Normalizing Data."))
+        seurat_object <- NormalizeData(object = seurat_object)
+      }
+
+      # Overwrite check
+      if ("S.Score" %in% colnames(x = seurat_object@meta.data) || "G2M.Score" %in% colnames(x = seurat_object@meta.data) || "Phase" %in% colnames(x = seurat_object@meta.data)) {
+        if (!overwrite) {
+          cli_abort(message = c("Columns with {.val S.Score}, {.val G2M.Score} and/or {.val Phase} already present in meta.data slot.",
+                                "i" = "*To run function and overwrite columns set parameter {.code overwrite = TRUE}*")
+          )
+        }
+        cli_inform(message = c("Columns with {.val S.Score}, {.val G2M.Score} and/or {.val Phase} already present in meta.data slot.",
+                               "i" = "Overwriting those columns as .code {overwrite = TRUE.}")
+        )
+      }
+
+      # Add Cell Cycle Scoring
+      cli_inform(message = "Adding {.field Cell Cycle Scoring to meta.data.} to meta.data.")
+      seurat_object <- CellCycleScoring(object = seurat_object, s.features = Seurat::cc.genes.updated.2019$s.genes, g2m.features = Seurat::cc.genes.updated.2019$g2m.genes)
+    }
+  }
+
+  # return object
+  return(seurat_object)
+}
+
+
 #' Calculate and add differences post-cell bender analysis
 #'
 #' Calculate the difference in features and UMIs per cell when both cell bender and raw assays are present.
@@ -408,7 +790,7 @@ Meta_Remove_Seurat <- function(
   meta_data_filtered <- meta_data %>%
     select(-all_of(x = existing_names))
 
-  if (barcodes_to_rownames) {
+  if (isTRUE(x = barcodes_to_rownames)) {
     # Check barcodes colname exists
     if (!barcodes_colname %in% colnames(x = meta_data)) {
       cli_abort(message = "{.code barcodes_colname}: {.val {barcodes_colname}} was not present in the column names of meta_data data.frame provided.")
@@ -539,7 +921,7 @@ Add_Sample_Meta <- function(
     rownames_to_column("barcodes")
 
   # remove
-  if (overwrite) {
+  if (isTRUE(x = overwrite)) {
     meta_seurat <- meta_seurat %>%
       select(-all_of(x = dup_columns))
   } else {
@@ -550,7 +932,7 @@ Add_Sample_Meta <- function(
   meta_merged <- left_join(x = meta_seurat, y = meta_data, by = setNames(join_by_meta, join_by_seurat))
 
   # Remove existing Seurat meta
-  if (length(x = dup_columns) > 0 && overwrite) {
+  if (length(x = dup_columns) > 0 && isTRUE(x = overwrite)) {
     meta_merged <- meta_merged %>%
       column_to_rownames("barcodes")
   } else {
@@ -600,6 +982,7 @@ Add_Sample_Meta <- function(
 #'
 #' @import cli
 #' @importFrom dplyr any_of grouped_df select slice
+#' @importFrom magrittr "%>%"
 #'
 #' @export
 #'
@@ -607,16 +990,16 @@ Add_Sample_Meta <- function(
 #'
 #' @examples
 #' library(Seurat)
-#' pbmc_small$batch <- sample(c("batch1", "batch2"), size = ncol(pbmc_small), replace = TRUE)
+#' pbmc_small[["batch"]] <- sample(c("batch1", "batch2"), size = ncol(pbmc_small), replace = TRUE)
 #'
 #' sample_meta <- Extract_Sample_Meta(object = pbmc_small, sample_name = "orig.ident")
 #'
 #' # Only return specific columns from meta data (orig.ident and batch)
-#' sample_meta <- Extract_Sample_Meta(object = pbmc_small, sample_name = "orig.ident",
+#' sample_meta2 <- Extract_Sample_Meta(object = pbmc_small, sample_name = "orig.ident",
 #' variables_include = "batch")
 #'
 #' # Return all columns from meta data
-#' sample_meta <- Extract_Sample_Meta(object = pbmc_small, sample_name = "orig.ident",
+#' sample_meta3 <- Extract_Sample_Meta(object = pbmc_small, sample_name = "orig.ident",
 #' include_all = TRUE)
 #'
 
@@ -641,9 +1024,9 @@ Extract_Sample_Meta <- function(
 
   # Generate nCount and nFeature variable vectors for exclusion
   if (is.null(x = variables_exclude)) {
-    nFeature_cols <- grep(x = colnames(object@meta.data), pattern = "^nFeature", value = TRUE)
+    nFeature_cols <- grep(x = colnames(x = object@meta.data), pattern = "^nFeature", value = TRUE)
 
-    nCount_cols <- grep(x = colnames(object@meta.data), pattern = "^nCount", value = TRUE)
+    nCount_cols <- grep(x = colnames(x = object@meta.data), pattern = "^nCount", value = TRUE)
 
     combined_exclude <- c(nFeature_cols, nCount_cols, "percent_mito", "percent_ribo", "percent_mito_ribo", "log10GenesPerUMI")
 
@@ -703,7 +1086,7 @@ Extract_Sample_Meta <- function(
   rownames(x = sample_meta_df) <- NULL
 
   # Filter data.frame
-  if (include_all) {
+  if (isTRUE(x = include_all)) {
     sample_meta_df_filtered <- sample_meta_df
   } else {
     if (length(x = include_meta_list[[1]]) > 0) {
@@ -774,7 +1157,7 @@ Store_Misc_Info_Seurat <- function(
   # Check if name already present
   misc_present <- names(x = seurat_object@misc)
   if (data_name %in% misc_present) {
-    if (!overwrite) {
+    if (isFALSE(x = overwrite)) {
       cli_abort(message = c("Item(s) named: {.val {data_name}} already present in @misc slot.",
                             "i" = "*To run function and overwrite items set parameter {.code overwrite = TRUE} or change {.code data_name}*")
       )
@@ -793,7 +1176,7 @@ Store_Misc_Info_Seurat <- function(
 
   # Check class of data
   if (inherits(x = data_to_store, what = "list")) {
-    if (list_as_list) {
+    if (isTRUE(x = list_as_list)) {
       # Check length of name
       if (length(x = data_name) != 1) {
         cli_abort(message = "When storing as list the length {.code data_name} must be {.field 1 (one)}.")
